# arpes.plotting.qt\_tool.utils module

**arpes.plotting.qt\_tool.utils.pretty\_key\_event(event)**

> Key Event -\> List\[str\] in order to be able to prettily print keys
> :param event: :return:

**class arpes.plotting.qt\_tool.utils.KeyBinding(label, chord,
handler)**

> Bases: `tuple`
> 
> `chord`
> 
> > Alias for field number 1
> 
> `handler`
> 
> > Alias for field number 2
> 
> `label`
> 
> > Alias for field number 0

**arpes.plotting.qt\_tool.utils.layout(\*children, layout\_cls=None,
widget=None)**

**arpes.plotting.qt\_tool.utils.hlayout(\*args,**kwargs)\*\*

**arpes.plotting.qt\_tool.utils.vlayout(\*args,**kwargs)\*\*

**arpes.plotting.qt\_tool.utils.tabs(\*children)**

**arpes.plotting.qt\_tool.utils.label(text,**kwargs)\*\*
